@@ -95,6 +95,7 @@ class VariableOsInstallX11Resolution(ResolutionVariable):
     type = 'choiceedit'
     opt = ['-X']
     metavalue = "<width>x<height>"
+    fallback_resolution = "1024x768"
 
     def init(self):
         self.help = _("set the Xorg resolution")
@@ -104,9 +105,9 @@ class VariableOsInstallX11Resolution(ResolutionVariable):
         # get resolution from xorg.log
         res = self.Get('os_x11_resolution')
         if res or self.Get('os_install_root_type') in ('livecd','usb-hdd'):
-            return res
+            return res or self.fallback_resolution
         else:
-            return "1024x768"
+            return self.fallback_resolution
 
 class VariableOsInstallX11VideoAvailable(VideoVariable):
     """
