@@ -54,6 +54,11 @@ class VariableOsInstallLinguas(LocaleVariable):
                               lines))
             return linguas[-1] if linguas else ""
         makeconf = '/etc/make.conf'
+
+        emerge_config = self.Get('cl_emerge_config')
+        if emerge_config and "LINGUAS" in emerge_config:
+            return emerge_config['LINGUAS'].encode('UTF-8')
+
         infocommand = ['emerge','--info']
         defaultLinguas = "bg en de es fr it pl pt_BR ru uk"
         # get linguas from make.conf, emerge --info or default
